## Publishing new versions

To publish new versions:
- change the code inside /arccanet
- update the version in the setup.py file
- push to master
- make sure the deploy succeeds

## TODO
- Create development branch and versions
- Find a way to develop real-time with Arccanet Backend
- Find a way to auto increment package version on deploys